@@ -80,7 +80,7 @@ impl Checkout {
 impl Checkout {
     async fn enter_shopping_state<C: Context + Send>(&mut self, ctx: &mut C) -> Result<(), Error> {
         self.reset_shipping_options();
-        ctx.free_items(&self.id, &self.items).await?;
+        ctx.free_items(&self.items).await?;
         Ok(self.state = State::Shopping)
     }
 
@@ -89,7 +89,7 @@ impl Checkout {
         ctx: &mut C,
     ) -> Result<(), Error> {
         self.reset_shipping_options();
-        match ctx.reserve_items(&self.id, &self.items).await? {
+        match ctx.reserve_items(&self.items).await? {
             ReserveResult::Success(deadline) => {
                 if let Some(address) = &self.shipping_address {
                     self.shipping_quotes = ctx
@@ -159,7 +159,7 @@ impl Checkout {
                     return Ok(());
                 }
 
-                ctx.free_items(&self.id, &self.items).await?;
+                ctx.free_items(&self.items).await?;
                 self.enter_items_confirmed_state(ctx).await
             }
             State::Shopping => self.enter_items_confirmed_state(ctx).await,
