@@ -12,6 +12,12 @@ pub struct StockIssue {
     max_available: u64,
 }
 
+#[derive(Debug, Serialize, Deserialize, JsonSchema)]
+pub struct StockUnit {
+    sku: String,
+    quantity: u64,
+}
+
 pub enum ReserveResult {
     Success(DateTime<Utc>),
     StockIssue(Vec<StockIssue>),
@@ -19,16 +25,18 @@ pub enum ReserveResult {
 
 #[async_trait]
 pub trait InventoryController {
-    async fn reserve_items(
-        &mut self,
-        _co_id: &str,
-        _items: &Vec<Item>,
-    ) -> Result<ReserveResult, Error> {
+    async fn reserve_items(&mut self, _items: &Vec<Item>) -> Result<ReserveResult, Error> {
         let deadline = Utc::now() + Duration::days(1);
         Ok(ReserveResult::Success(deadline))
     }
 
-    async fn free_items(&mut self, _co_id: &str, _items: &Vec<Item>) -> Result<(), Error> {
+    async fn free_items(&mut self, _items: &Vec<Item>) -> Result<(), Error> {
         Ok(())
     }
 }
+
+#[async_trait]
+pub trait StockController {
+    async fn add_stock(&mut self, stock_units: &Vec<StockUnit>) -> Result<(), Error>;
+    async fn remove_stock(&mut self, stock_units: &Vec<StockUnit>) -> Result<(), Error>;
+}
