@@ -12,7 +12,6 @@ pub async fn create_handler<C: Context + Send>(
     args: <C as PaymentProcessor>::InitiateArgs,
 ) -> Result<
     Payment<
-        <C as PaymentProcessor>::CorrelationID,
         <C as PaymentProcessor>::PrivateData,
         <C as PaymentProcessor>::PublicData,
         <C as PaymentProcessor>::ProcessArgs,
@@ -29,7 +28,6 @@ pub async fn step_handler<C: Context + Send>(
     args: <C as PaymentProcessor>::ProcessArgs,
 ) -> Result<
     Payment<
-        <C as PaymentProcessor>::CorrelationID,
         <C as PaymentProcessor>::PrivateData,
         <C as PaymentProcessor>::PublicData,
         <C as PaymentProcessor>::ProcessArgs,
@@ -50,11 +48,10 @@ pub async fn step_handler<C: Context + Send>(
 pub async fn callback_handler<C: Context + Send>(
     internal_ctx: &InternalContext,
     ctx: &mut C,
-    correlation_id: &<C as PaymentProcessor>::CorrelationID,
+    correlation_id: &str,
     args: <C as PaymentProcessor>::ProcessArgs,
 ) -> Result<
     Payment<
-        <C as PaymentProcessor>::CorrelationID,
         <C as PaymentProcessor>::PrivateData,
         <C as PaymentProcessor>::PublicData,
         <C as PaymentProcessor>::ProcessArgs,
@@ -74,11 +71,7 @@ pub async fn callback_handler<C: Context + Send>(
     Ok(payment)
 }
 
-pub async fn process_handler<C: Context + Send>(
-    internal_ctx: &InternalContext,
-    ctx: &mut C,
-    id: &str,
-) -> Result<(), Error> {
+pub async fn process_handler<C: Context + Send>(ctx: &mut C, id: &str) -> Result<(), Error> {
     let maybe_payment = ctx.get_payment_for_update(id).await?;
     if maybe_payment.is_none() {
         // this isn't supposed to happen. maybe log the error and move on
@@ -95,7 +88,7 @@ pub async fn process_handler<C: Context + Send>(
 
     let mut checkout = maybe_checkout.unwrap();
 
-    process(internal_ctx, ctx, &mut payment, &mut checkout).await?;
+    process(ctx, &mut payment, &mut checkout).await?;
 
     Ok(())
 }
@@ -105,7 +98,6 @@ pub async fn cancel_handler<C: Context + Send>(
     id: &str,
 ) -> Result<
     Payment<
-        <C as PaymentProcessor>::CorrelationID,
         <C as PaymentProcessor>::PrivateData,
         <C as PaymentProcessor>::PublicData,
         <C as PaymentProcessor>::ProcessArgs,
