@@ -12,12 +12,12 @@ use crate::money::Money;
 pub mod handlers;
 
 #[derive(Serialize, Deserialize, JsonSchema)]
-pub struct Payment<CorrelationID, PrivateData, PublicData, ProcessArgs> {
+pub struct Payment<PrivateData, PublicData, ProcessArgs> {
     pub id: String,
     pub state: PaymentState<ProcessArgs>,
     pub checkout_id: String,
     pub charge_amount: Money,
-    pub data: PaymentData<CorrelationID, PrivateData, PublicData>,
+    pub data: PaymentData<PrivateData, PublicData>,
 }
 
 #[derive(Serialize, Deserialize, JsonSchema)]
@@ -30,7 +30,6 @@ pub enum PaymentState<ProcessArgs> {
 
 #[async_trait]
 pub trait PaymentProcessor {
-    type CorrelationID: Sync + PartialEq;
     type InitiateArgs: Sync;
     type ProcessArgs: Sync;
     type PrivateData: Sync;
@@ -40,7 +39,7 @@ pub trait PaymentProcessor {
     async fn initiate_payment(
         &mut self,
         _args: &Self::InitiateArgs,
-    ) -> Result<PaymentData<Self::CorrelationID, Self::PrivateData, Self::PublicData>, Error> {
+    ) -> Result<PaymentData<Self::PrivateData, Self::PublicData>, Error> {
         Ok(PaymentData {
             correlation_id: None,
             private_data: None,
@@ -50,24 +49,14 @@ pub trait PaymentProcessor {
 
     async fn process_payment(
         &mut self,
-        payment: &Payment<
-            Self::CorrelationID,
-            Self::PrivateData,
-            Self::PublicData,
-            Self::ProcessArgs,
-        >,
+        payment: &Payment<Self::PrivateData, Self::PublicData, Self::ProcessArgs>,
         args: &Self::ProcessArgs,
-    ) -> Result<ProcessingResult<Self::CorrelationID, Self::PrivateData, Self::PublicData>, Error>;
+    ) -> Result<ProcessingResult<Self::PrivateData, Self::PublicData>, Error>;
 
     // this is called synchronously and only once per revert request
     async fn cancel_payment(
         &mut self,
-        payment: &Payment<
-            Self::CorrelationID,
-            Self::PrivateData,
-            Self::PublicData,
-            Self::ProcessArgs,
-        >,
+        payment: &Payment<Self::PrivateData, Self::PublicData, Self::ProcessArgs>,
     ) -> Result<CancellationResult, Error>;
 }
 
@@ -76,7 +65,6 @@ pub trait PaymentStore: PaymentProcessor {
     async fn create_payment(
         &mut self,
         payment: &Payment<
-            <Self as PaymentProcessor>::CorrelationID,
             <Self as PaymentProcessor>::PrivateData,
             <Self as PaymentProcessor>::PublicData,
             <Self as PaymentProcessor>::ProcessArgs,
@@ -86,7 +74,6 @@ pub trait PaymentStore: PaymentProcessor {
     async fn update_payment(
         &mut self,
         payment: &Payment<
-            <Self as PaymentProcessor>::CorrelationID,
             <Self as PaymentProcessor>::PrivateData,
             <Self as PaymentProcessor>::PublicData,
             <Self as PaymentProcessor>::ProcessArgs,
@@ -99,7 +86,6 @@ pub trait PaymentStore: PaymentProcessor {
     ) -> Result<
         Option<
             Payment<
-                <Self as PaymentProcessor>::CorrelationID,
                 <Self as PaymentProcessor>::PrivateData,
                 <Self as PaymentProcessor>::PublicData,
                 <Self as PaymentProcessor>::ProcessArgs,
@@ -114,7 +100,6 @@ pub trait PaymentStore: PaymentProcessor {
     ) -> Result<
         Option<
             Payment<
-                <Self as PaymentProcessor>::CorrelationID,
                 <Self as PaymentProcessor>::PrivateData,
                 <Self as PaymentProcessor>::PublicData,
                 <Self as PaymentProcessor>::ProcessArgs,
@@ -125,11 +110,10 @@ pub trait PaymentStore: PaymentProcessor {
 
     async fn get_payment_for_update_by_correlation_id(
         &mut self,
-        _id: &<Self as PaymentProcessor>::CorrelationID,
+        _id: &str,
     ) -> Result<
         Option<
             Payment<
-                <Self as PaymentProcessor>::CorrelationID,
                 <Self as PaymentProcessor>::PrivateData,
                 <Self as PaymentProcessor>::PublicData,
                 <Self as PaymentProcessor>::ProcessArgs,
@@ -141,9 +125,9 @@ pub trait PaymentStore: PaymentProcessor {
     }
 }
 
-pub struct ProcessingResult<CorrelationID, PrivateData, PublicData> {
+pub struct ProcessingResult<PrivateData, PublicData> {
     pub state: InternalPaymentState,
-    pub data: PaymentData<CorrelationID, PrivateData, PublicData>,
+    pub data: PaymentData<PrivateData, PublicData>,
 }
 
 pub struct CancellationResult {
@@ -151,8 +135,8 @@ pub struct CancellationResult {
 }
 
 #[derive(Serialize, Deserialize, JsonSchema)]
-pub struct PaymentData<CorrelationID, PrivateData, PublicData> {
-    pub correlation_id: Option<CorrelationID>,
+pub struct PaymentData<PrivateData, PublicData> {
+    pub correlation_id: Option<String>,
     pub private_data: Option<PrivateData>,
     pub public_data: Option<PublicData>,
 }
@@ -173,7 +157,6 @@ async fn new<C: Context + Send>(
     args: <C as PaymentProcessor>::InitiateArgs,
 ) -> Result<
     Payment<
-        <C as PaymentProcessor>::CorrelationID,
         <C as PaymentProcessor>::PrivateData,
         <C as PaymentProcessor>::PublicData,
         <C as PaymentProcessor>::ProcessArgs,
@@ -203,7 +186,6 @@ pub async fn queue_for_processing<C: Context + Send>(
     internal_ctx: &InternalContext,
     ctx: &mut C,
     payment: &mut Payment<
-        <C as PaymentProcessor>::CorrelationID,
         <C as PaymentProcessor>::PrivateData,
         <C as PaymentProcessor>::PublicData,
         <C as PaymentProcessor>::ProcessArgs,
@@ -238,10 +220,8 @@ pub async fn queue_for_processing<C: Context + Send>(
 }
 
 pub async fn process<C: Context + Send>(
-    internal_ctx: &InternalContext,
     ctx: &mut C,
     payment: &mut Payment<
-        <C as PaymentProcessor>::CorrelationID,
         <C as PaymentProcessor>::PrivateData,
         <C as PaymentProcessor>::PublicData,
         <C as PaymentProcessor>::ProcessArgs,
@@ -263,21 +243,7 @@ pub async fn process<C: Context + Send>(
             ctx.update_payment(payment).await?;
 
             match payment.state {
-                PaymentState::Succeeded => {
-                    internal_ctx
-                        .checkout_completion_topic
-                        .clone()
-                        .publish(&payment.checkout_id)
-                        .await
-                        .map_err(|_| {
-                            new_application_error(
-                                "UPSTREAM_ERROR",
-                                "couldn't send message to payment processing topic",
-                            )
-                        })?;
-
-                    checkout.complete(ctx).await
-                }
+                PaymentState::Succeeded => checkout.complete(ctx).await,
                 PaymentState::Cancelled => checkout.revert(ctx).await,
                 _ => Ok(()),
             }
@@ -289,7 +255,6 @@ pub async fn process<C: Context + Send>(
 pub async fn cancel<C: Context + Send>(
     ctx: &mut C,
     payment: &mut Payment<
-        <C as PaymentProcessor>::CorrelationID,
         <C as PaymentProcessor>::PrivateData,
         <C as PaymentProcessor>::PublicData,
         <C as PaymentProcessor>::ProcessArgs,
